@@ -2,8 +2,8 @@
  *
  * FLAPPING.C - State flap detection and handling routines for Nagios
  *
- * Copyright (c) 2001-2008 Ethan Galstad (nagios@nagios.org)
- * Last Modified:   01-28-2008
+ * Copyright (c) 2001-2005 Ethan Galstad (nagios@nagios.org)
+ * Last Modified:   08-12-2005
  *
  * License:
  *
@@ -41,8 +41,6 @@ extern double   high_service_flap_threshold;
 extern double   low_host_flap_threshold;
 extern double   high_host_flap_threshold;
 
-extern unsigned long    modified_host_process_attributes;
-extern unsigned long    modified_service_process_attributes;
 
 /******************************************************************/
 /******************** FLAP DETECTION FUNCTIONS ********************/
@@ -342,9 +340,6 @@ void clear_service_flap(service *svc, double percent_change, double high_thresho
 	broker_flapping_data(NEBTYPE_FLAPPING_STOP,NEBFLAG_NONE,NEBATTR_FLAPPING_STOP_NORMAL,SERVICE_FLAPPING,svc,percent_change,high_threshold,low_threshold,NULL);
 #endif
 
-	/* send a notification */
-	service_notification(svc,NOTIFICATION_FLAPPINGSTOP,NULL,NULL);
-
 	/* should we send a recovery notification? */
 	if(svc->check_flapping_recovery_notification==TRUE && svc->current_state==STATE_OK)
 		service_notification(svc,NOTIFICATION_NORMAL,NULL,NULL);
@@ -352,6 +347,9 @@ void clear_service_flap(service *svc, double percent_change, double high_thresho
 	/* clear the recovery notification flag */
 	svc->check_flapping_recovery_notification=FALSE;
 
+	/* send a notification */
+	service_notification(svc,NOTIFICATION_FLAPPINGSTOP,NULL,NULL);
+
 #ifdef DEBUG0
 	printf("clear_service_flap() end\n");
 #endif
@@ -429,9 +427,6 @@ void clear_host_flap(host *hst, double percent_change, double high_threshold, do
 	broker_flapping_data(NEBTYPE_FLAPPING_STOP,NEBFLAG_NONE,NEBATTR_FLAPPING_STOP_NORMAL,HOST_FLAPPING,hst,percent_change,high_threshold,low_threshold,NULL);
 #endif
 
-	/* send a notification */
-	host_notification(hst,NOTIFICATION_FLAPPINGSTOP,NULL,NULL);
-
 	/* should we send a recovery notification? */
 	if(hst->check_flapping_recovery_notification==TRUE && hst->current_state==HOST_UP)
 		host_notification(hst,NOTIFICATION_NORMAL,NULL,NULL);
@@ -439,6 +434,9 @@ void clear_host_flap(host *hst, double percent_change, double high_threshold, do
 	/* clear the recovery notification flag */
 	hst->check_flapping_recovery_notification=FALSE;
 
+	/* send a notification */
+	host_notification(hst,NOTIFICATION_FLAPPINGSTOP,NULL,NULL);
+
 #ifdef DEBUG0
 	printf("clear_host_flap() end\n");
 #endif
@@ -459,10 +457,6 @@ void enable_flap_detection_routines(void){
 	printf("enable_flap_detection() start\n");
 #endif
 
-	/* set the attribute modified flag */
-	modified_host_process_attributes|=MODATTR_FLAP_DETECTION_ENABLED;
-	modified_service_process_attributes|=MODATTR_FLAP_DETECTION_ENABLED;
-
 	/* set flap detection flag */
 	enable_flap_detection=TRUE;
 
@@ -485,11 +479,6 @@ void disable_flap_detection_routines(void){
 	printf("disable_flap_detection() start\n");
 #endif
 
-	/* set the attribute modified flag */
-	modified_host_process_attributes|=MODATTR_FLAP_DETECTION_ENABLED;
-	modified_service_process_attributes|=MODATTR_FLAP_DETECTION_ENABLED;
-
-
 	/* set flap detection flag */
 	enable_flap_detection=FALSE;
 
@@ -513,9 +502,6 @@ void enable_host_flap_detection(host *hst){
 	printf("enable_host_flap_detection() start\n");
 #endif
 
-	/* set the attribute modified flag */
-	hst->modified_attributes|=MODATTR_FLAP_DETECTION_ENABLED;
-
 	/* nothing to do... */
 	if(hst->flap_detection_enabled==TRUE)
 		return;
@@ -550,9 +536,6 @@ void disable_host_flap_detection(host *hst){
 	printf("disable_host_flap_detection() start\n");
 #endif
 
-	/* set the attribute modified flag */
-	hst->modified_attributes|=MODATTR_FLAP_DETECTION_ENABLED;
-
 	/* nothing to do... */
 	if(hst->flap_detection_enabled==FALSE)
 		return;
@@ -603,9 +586,6 @@ void enable_service_flap_detection(service *svc){
 	printf("enable_service_flap_detection() start\n");
 #endif
 
-	/* set the attribute modified flag */
-	svc->modified_attributes|=MODATTR_FLAP_DETECTION_ENABLED;
-
 	/* nothing to do... */
 	if(svc->flap_detection_enabled==TRUE)
 		return;
@@ -640,9 +620,6 @@ void disable_service_flap_detection(service *svc){
 	printf("disable_service_flap_detection() start\n");
 #endif
 
-	/* set the attribute modified flag */
-	svc->modified_attributes|=MODATTR_FLAP_DETECTION_ENABLED;
-
 	/* nothing to do... */
 	if(svc->flap_detection_enabled==FALSE)
 		return;
@@ -683,3 +660,9 @@ void disable_service_flap_detection(service *svc){
 
 	return;
         }
+
+
+
+
+
+
